@@ -480,37 +480,37 @@ const QString Titraqform::getRowdata(void) const
         // Build the row data string one field at a time, adding seps inbetween
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXLINE);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + Tempstring;
+            Rowdata += Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXUSER);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXGUID);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXCRC);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXREV);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXDATE);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXSTART);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXFINISH);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXAMOUNT);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXTASK);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Tempstring = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXREMARK);
         if (!Tempstring.isEmpty())
-            Rowdata = Rowdata + trUtf8(TITRAQ_SEPARATORTOK) + Tempstring;
+            Rowdata += TITRAQ_SEPARATORTOK + Tempstring;
         Rowdata += trUtf8("\n");    // Finish off line
     }
 
