@@ -1183,14 +1183,19 @@ void Titraqform::configPrefs(void)
 
     // Colour preferences
     int nRed, nGreen, nBlue;
-    QColorGroup Origcolour;
+    QColorGroup Origcolour, Altcolour;
     const QColor Origlight = QColor(TITRAQ_DEFLIGHTRED, TITRAQ_DEFLIGHTGREEN, TITRAQ_DEFLIGHTBLUE);
     const QColor Origdark  = QColor(TITRAQ_DEFDARKRED, TITRAQ_DEFDARKGREEN, TITRAQ_DEFDARKBLUE);
+    const QColor Altlight = QColor(TITRAQ_DEFLTALTRED, TITRAQ_DEFLTALTGREEN, TITRAQ_DEFLTALTBLUE);
+    const QColor Altdark  = QColor(TITRAQ_DEFDKALTRED, TITRAQ_DEFDKALTGREEN, TITRAQ_DEFDKALTBLUE);
 
     // Set colours to revert to if user screws up and wants out
     Origcolour.setColor(QColorGroup::Foreground, Origlight);
     Origcolour.setColor(QColorGroup::Background, Origdark);
     pUserpanel->setOrigcolour(&Origcolour);
+    Altcolour.setColor(QColorGroup::Foreground, Altlight);
+    Altcolour.setColor(QColorGroup::Background, Altdark);
+    pUserpanel->setAltcolour(&Altcolour);
 
     // Set colour preferences saved from last session
     nRed   = m_pPrefs->getNumber(TITRAQ_PREFLIGHTRED, TITRAQ_DEFLIGHTRED);
